hepstats.splot
--------------

hepstats.splot.sweights
=======================

.. currentmodule:: hepstats.splot.sweights

.. autosummary::

    compute_sweights
    is_sum_of_extended_pdfs

hepstats.splot.exceptions
=========================

.. currentmodule:: hepstats.splot.exceptions

.. autosummary::

    ModelNotFittedToData
